@@ -1,6 +1,6 @@
 package Dancer::Plugin::MemcachedFast;
 BEGIN {
-  $Dancer::Plugin::MemcachedFast::VERSION = '0.110570';
+  $Dancer::Plugin::MemcachedFast::VERSION = '0.110620';
 }
 use strict;
 use warnings;
@@ -35,7 +35,7 @@ register memcached_compress => sub {
 
 register memcached_get_or_set => sub {
     $cache->get( $_[0] )
-      or $cache->set( $_[0], ref $_[1] eq 'CODE' ? $_[1]->() : $_[1] )
+      or do { my $ret; $cache->set( $_[0], $ret = ref $_[1] eq 'CODE' ? $_[1]->() : $_[1] ); $ret }
       or $_[1];
 };
 
